@@ -120,9 +120,7 @@ def _markdown(handle, **kwargs):
 @opener
 def _yaml(handle, **kwargs):
     import yaml
-    defaults = {'Loader': yaml.SafeLoader}
-    kwargs = {k: kwargs.pop(k, v) for k, v in defaults.items()}
-    return yaml.load(handle.read(), **kwargs)   # nosec: SafeLoader
+    return yaml.safe_load(handle.read())
 
 
 def _template(path, **kwargs):
@@ -255,7 +253,7 @@ def open(path, callback=None, transform=None, rel=False, **kwargs):
 
     - ``bin``: reads binary files using io.open
     - ``text`` or ``txt``: reads text files using io.open
-    - ``yaml``: reads files using yaml.load via io.open
+    - ``yaml``: reads files using yaml.safe_load via io.open
     - ``config``: reads files using using :py:class:`gramex.config.PathConfig`.
       Same as ``yaml``, but allows ``import:`` and variable substitution.
     - ``json``: reads files using json.load via io.open
@@ -319,6 +317,13 @@ def open(path, callback=None, transform=None, rel=False, **kwargs):
     if rel:
         stack = inspect.getouterframes(inspect.currentframe(), 2)
         folder = os.path.dirname(os.path.abspath(stack[1][1]))
+        # If we're calling from a FileHandler template, use the template's path
+        if stack[1][1] == '<string>.generated.py':
+            g = stack[1][0].f_globals
+            if 'handler' in g and g['handler'].__class__.__name__ == 'FileHandler':
+                folder = os.path.dirname(g['handler'].file)
+            else:
+                app_log.warning(f'gramex.cache.open: rel= failed for {path}')
         path = os.path.join(folder, path)
 
     original_callback = callback
@@ -449,10 +454,14 @@ def _table_status(engine, tables):
         # bandit security note: We use string substitution for DB and table names.
         # But these are validated via gramex.data._sql_safe, so we're fine.
         if dialect == 'mysql':
-            # https://dev.mysql.com/doc/refman/5.7/en/tables-table.html
+            # https://dev.mysql.com/doc/refman/8.0/en/information-schema-tables-table.html
             # Works only on MySQL 5.7 and above
             q = ('SELECT update_time FROM information_schema.tables WHERE ' +   # nosec
                  _wheres('table_schema', 'table_name', db, tables))
+        elif dialect == 'snowflake':
+            # https://docs.snowflake.com/en/sql-reference/info-schema/tables.html
+            q = ('SELECT last_altered FROM information_schema.tables WHERE ' +  # nosec
+                 _wheres('table_schema', 'table_name', db, tables))
         elif dialect == 'mssql':
             # https://goo.gl/b4aL9m
             q = ('SELECT last_user_update FROM sys.dm_db_index_usage_stats WHERE ' +    # nosec
@@ -463,10 +472,10 @@ def _table_status(engine, tables):
                  _wheres('schemaname', 'relname', 'public', tables))
         elif dialect == 'sqlite':
             if not db:
-                raise KeyError(f'gramex.cache.query does not support memory sqlite "{dialect}"')
+                raise KeyError(f'gramex.cache.query: does not support memory sqlite "{dialect}"')
             q = db
         else:
-            raise KeyError(f'gramex.cache.query cannot cache dialect "{dialect}" yet')
+            raise KeyError(f'gramex.cache.query: cannot cache dialect "{dialect}" yet')
         if dialect == 'sqlite':
             _STATUS_METHODS[key] = lambda: stat(q)
         else:
@@ -496,15 +505,20 @@ def query(sql, engine, state=None, **kwargs):
     store_cache = True
 
     if isinstance(state, (list, tuple)):
-        status = _table_status(engine, tuple(state))
+        try:
+            status = _table_status(engine, tuple(state))
+        except KeyError as e:
+            # Unknown SQLAlchemy dialects raise a KeyError.
+            # Warn and don't cache the table. (Otherwise, no new dialects can be used.)
+            app_log.warning(e.args[0] if len(e.args) > 0 else 'gramex.cache.query: state failed')
+            status, store_cache = object(), False
     elif isinstance(state, str):
         status = pd.read_sql(state, engine).to_dict(orient='list')
     elif callable(state):
         status = state()
     elif state is None:
         # Create a new status every time, so that the query is always re-run
-        status = object()
-        store_cache = False
+        status, store_cache = object(), False
     else:
         raise TypeError(f'gramex.cache.query(state=) must be a table list/query/fn, not {state!r}')
 
