@@ -3,8 +3,6 @@ import re
 import ast
 import copy
 import platform
-import six
-from six import iteritems
 import numpy as np
 import pandas as pd
 # lxml.etree is safe on https://github.com/tiran/defusedxml/tree/main/xmltestdata
@@ -39,7 +37,7 @@ def is_slide_allowed(change, slide, number):
         slide_number = change['slide-number']
         if isinstance(slide_number, (list, dict)):
             match = match and number in slide_number
-        elif isinstance(slide_number, six.integer_types):
+        elif isinstance(slide_number, int):
             match = match and number == slide_number
 
     # Restrict to specific slide title(s), if specified
@@ -50,7 +48,7 @@ def is_slide_allowed(change, slide, number):
         if isinstance(slide_title, (list, dict)):
             match = match and any(
                 re.search(expr, title, re.IGNORECASE) for expr in slide_title)
-        elif isinstance(slide_title, six.string_types):
+        elif isinstance(slide_title, str):
             match = match and re.search(slide_title, title, re.IGNORECASE)
     return match
 
@@ -141,7 +139,7 @@ def add_new_slide(dest, source_slide):
     '''Function to add a new slide to presentation.'''
     if dest is None:
         return
-    for key, value in six.iteritems(source_slide.part.rels):
+    for value in source_slide.part.rels.values():
         # Make sure we don't copy a notesSlide relation as that won't exist
         if "notesSlide" in value.reltype:
             continue
@@ -177,7 +175,7 @@ def manage_slides(prs, config):
     '''
     slide_numbers = config.pop('only', None)
     if slide_numbers:
-        if isinstance(slide_numbers, six.integer_types):
+        if isinstance(slide_numbers, int):
             slide_numbers = set([int(slide_numbers) - 1])
         elif isinstance(slide_numbers, list):
             slide_numbers = set([int(i) - 1 for i in slide_numbers])
@@ -373,19 +371,17 @@ def fill_color(**kwargs):
     srgbclr = srgbclr.rsplit('#')[-1].lower()
     srgbclr = srgbclr + ('0' * (6 - len(srgbclr)))
     if schemeclr:
-        s = '<a:schemeClr %s val="%s"/>' % (ns, schemeclr)
+        s = f'<a:schemeClr {ns} val="{schemeclr}"/>'
     elif srgbclr:
-        s = '<a:srgbClr %s val="%s"/>' % (ns, srgbclr)
+        s = f'<a:srgbClr {ns} val="{srgbclr}"/>'
     elif prstclr:
-        s = '<a:prstClr %s val="%s"/>' % (ns, prstclr)
+        s = f'<a:prstClr {ns} val="{prstclr}"/>'
     elif hslclr:
-        s = '<a:hslClr %s hue="%.0f" sat="%.2f%%" lum="%.2f%%"/>' % (
-            (ns,) + tuple(hslclr))
+        s = f'<a:hslClr {ns} hue="%.0f" sat="%.2f%%" lum="%.2f%%"/>' % tuple(hslclr)
     elif sysclr:
-        s = '<a:sysClr %s val="%s"/>' % (ns, sysclr)
+        s = f'<a:sysClr {ns} val="{sysclr}"/>'
     elif scrgbclr:
-        s = '<a:scrgbClr %s r="%.0f" g="%.0f" b="%.0f"/>' % ((ns,) + tuple(
-            scrgbclr))
+        s = f'<a:scrgbClr {ns} r="%.0f" g="%.0f" b="%.0f"/>' % tuple(scrgbclr)
     color = objectify.fromstring(s)
     return color
 
@@ -393,7 +389,7 @@ def fill_color(**kwargs):
 def xmlns(*prefixes):
     '''XML ns.'''
     elem_schema = make_element()
-    return ' '.join('xmlns:%s="%s"' % (pre, elem_schema['nsmap'][pre]) for pre in prefixes)
+    return ' '.join(f'xmlns:{pre}="{elem_schema["nsmap"][pre]}"' for pre in prefixes)
 
 
 def call(val, g, group, default):
@@ -405,16 +401,17 @@ def call(val, g, group, default):
 
 def cust_shape(x, y, w, h, _id):
     '''Custom shapes.'''
-    _cstmshape = '<p:sp ' + xmlns('p', 'a') + '>'
-    _cstmshape = _cstmshape + '''<p:nvSpPr>
-            <p:cNvPr id='%s' name='%s'/>
+    return objectify.fromstring(f'''
+        <p:sp {xmlns("p", "a")}>
+          <p:nvSpPr>
+            <p:cNvPr id='{_id}' name='Freeform {_id}'/>
             <p:cNvSpPr/>
             <p:nvPr/>
           </p:nvSpPr>
           <p:spPr>
             <a:xfrm>
-              <a:off x='%s' y='%s'/>
-              <a:ext cx='%s' cy='%s'/>
+              <a:off x='{x}' y='{y}'/>
+              <a:ext cx='{w}' cy='{h}'/>
             </a:xfrm>
             <a:custGeom>
               <a:avLst/>
@@ -424,9 +421,7 @@ def cust_shape(x, y, w, h, _id):
               <a:rect l='0' t='0' r='0' b='0'/>
             </a:custGeom>
           </p:spPr>
-        </p:sp>'''
-    shp = _cstmshape % (_id, 'Freeform %d' % _id, x, y, w, h)
-    return objectify.fromstring(shp)
+        </p:sp>''')
 
 
 def draw_sankey(data, spec):
@@ -454,7 +449,7 @@ def draw_sankey(data, spec):
     result = call(text, g, group, '')
     frame['text'] = result
     # Add all attrs to the frame as well
-    for key, val in iteritems(attrs):
+    for key, val in attrs.items():
         frame[key] = call(val, g, group, None)
     if 'stroke' not in attrs:
         frame['stroke'] = default_stroke
