@@ -3,7 +3,7 @@
 from .transforms import build_transform, build_log_info, condition, flattener, once
 from .transforms import handler, Header
 from .badgerfish import badgerfish
-from .template import template, sass, scss, vue, CacheLoader
+from .template import template, sass, scss, ts, vue, CacheLoader
 from .rmarkdown import rmarkdown
 from .auth import ensure_single_session
 from .twitterstream import TwitterStream
@@ -15,6 +15,7 @@ __all__ = [
     'template',
     'sass',
     'scss',
+    'ts',
     'vue',
     'rmarkdown',
     'ensure_single_session',
