@@ -16,8 +16,8 @@ class TestProcessHandler(TestGramex):
             cwd = cwd or gramex.paths.base.absolute()
             self.assertIn('stdout starts', lines)
             self.assertIn('stdout ends', lines)
-            self.assertIn('os.getcwd: %s' % cwd, lines)
-            self.assertIn('sys.argv[0]: %s' % cmd, lines)
+            self.assertIn(f'os.getcwd: {cwd}', lines)
+            self.assertIn(f'sys.argv[0]: {cmd}', lines)
             self.assertIn('sys.argv[1]: a', lines)
             self.assertIn('sys.argv[2]: 1', lines)
             self.assertIn('sys.argv[3]: x y', lines)
